==> paraview-v0.2.0.zip: paraview-v0.2.0/ParaView/Widgets/vtkKWWidgetCollection.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKWWidgetCollection.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkKWWidgetCollection - a collection of widgets
// .SECTION DescriptionCollection
// vtkKWWidgetCollection represents and provides methods to manipulate a list 
// of widgets. The list is unsorted and duplicate entries are not prevented.

#ifndef __vtkKWWidgetC_h
#define __vtkKWWidgetC_h

#include "vtkCollection.h"
class vtkKWWidget;

class VTK_EXPORT vtkKWWidgetCollection : public vtkCollection
{
public:
  static vtkKWWidgetCollection *New();
  vtkTypeMacro(vtkKWWidgetCollection,vtkCollection);

  // Description:
  // Add an KWWidget to the list.
  void AddItem(vtkKWWidget *a);

  // Description:
  // Remove an KWWidget from the list.
  void RemoveItem(vtkKWWidget *a);

  // Description:
  // Determine whether a particular KWWidget is present. 
  // Returns its position in the list.
  int IsItemPresent(vtkKWWidget *a);

  // Description:
  // Get the next KWWidget in the list.
  vtkKWWidget *GetNextKWWidget();

  // Description:
  // Get the last KWWidget in the list.
  vtkKWWidget *GetLastKWWidget();

protected:
  vtkKWWidgetCollection() {};
  ~vtkKWWidgetCollection() {};
  vtkKWWidgetCollection(const vtkKWWidgetCollection&) {};
  void operator=(const vtkKWWidgetCollection&) {};

};

inline void vtkKWWidgetCollection::AddItem(vtkKWWidget *a) 
{
  this->vtkCollection::AddItem((vtkObject *)a);
}

inline void vtkKWWidgetCollection::RemoveItem(vtkKWWidget *a) 
{
  this->vtkCollection::RemoveItem((vtkObject *)a);
}

inline int vtkKWWidgetCollection::IsItemPresent(vtkKWWidget *a) 
{
  return this->vtkCollection::IsItemPresent((vtkObject *)a);
}

#endif

==> paraview-v0.6.0.zip: paraview-v0.6.0/ParaView/Widgets/vtkKWWidgetCollection.h <==
/*=========================================================================

  Program:   Visualization Toolkit
  Module:    vtkKWWidgetCollection.h
  Language:  C++
  Date:      $Date$
  Version:   $Revision$

Copyright (c) 2000-2001 Kitware Inc. 469 Clifton Corporate Parkway,
Clifton Park, NY, 12065, USA.
All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

 * Redistributions of source code must retain the above copyright notice,
   this list of conditions and the following disclaimer.

 * Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

 * Neither the name of Kitware nor the names of any contributors may be used
   to endorse or promote products derived from this software without specific 
   prior written permission.

 * Modified source versions must be plainly marked as such, and must not be
   misrepresented as being the original software.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
// .NAME vtkKWWidgetCollection - a collection of widgets
// .SECTION DescriptionCollection
// vtkKWWidgetCollection represents and provides methods to manipulate a list 
// of widgets. The list is unsorted and duplicate entries are not prevented.

#ifndef __vtkKWWidgetC_h
#define __vtkKWWidgetC_h

#include "vtkCollection.h"
class vtkKWWidget;

class VTK_EXPORT vtkKWWidgetCollection : public vtkCollection
{
public:
  static vtkKWWidgetCollection *New();
  vtkTypeRevisionMacro(vtkKWWidgetCollection,vtkCollection);
  void PrintSelf(ostream& os, vtkIndent indent);

  // Description:
  // Add an KWWidget to the list.
  void AddItem(vtkKWWidget *a);

  // Description:
  // Remove an KWWidget from the list.
  void RemoveItem(vtkKWWidget *a);

  // Description:
  // Determine whether a particular KWWidget is present. 
  // Returns its position in the list.
  int IsItemPresent(vtkKWWidget *a);

  // Description:
  // Get the next KWWidget in the list.
  vtkKWWidget *GetNextKWWidget();

  // Description:
  // Get the last KWWidget in the list.
  vtkKWWidget *GetLastKWWidget();

protected:
  vtkKWWidgetCollection() {};
  ~vtkKWWidgetCollection() {};

private:
  vtkKWWidgetCollection(const vtkKWWidgetCollection&); // Not implemented
  void operator=(const vtkKWWidgetCollection&); // Not implemented
};

#endif
